import argparse
import sys

from hombre.postinstall import register
from hombre.constants import PrecheckPlugin
from hombre.precheck.plugin_base import PluginBase

# initialize plugins for precheck
PRECHECK_PLUGINS = {p.id: p for p in PluginBase.plugins}


def main():
    parser = argparse.ArgumentParser(description='Python utilities module for NSX Intelligence')
    parser.add_argument('--register-ui-plugin', action="store_true", required=False,
                        help="Invoke API on NSX manager to register Intelligence UI plugin")
    parser.add_argument('--unregister-ui-plugin', action="store_true", required=False,
                        help="Invoke API on NSX manager to UN-register Intelligence UI plugin")
    parser.add_argument('--enable-intelligence', action="store_true", required=False,
                        help="Invoke API on NSX manager to enable Intelligence")
    parser.add_argument('--disable-intelligence', action="store_true", required=False,
                        help="Invoke API on NSX manager to disable Intelligence")
    parser.add_argument('--validate-transport-node-count', action="store_true", required=False,
                        help="Invoke API on NSX manager to retrieve count of transport nodes "
                             "and validate that it is within limits")
    parser.add_argument('--validate-license', action="store_true", required=False,
                        help="Invoke API on NSX manager to retrieve licenses and "
                             "validate if minimum requirements are met")
    parser.add_argument('--validate-platform-type', action="store_true", required=False,
                        help="Invoke API on monitor app to validate if minimum platform "
                             "form factor requirement is satisfied")
    parser.add_argument('--validate-advanced-license', action="store_true", required=False,
                        help="Invoke API on NSX manager to retrieve licenses and "
                             "check if advanced license is installed")
    args = parser.parse_args()

    if args.register_ui_plugin:
        register.ui_plugin()
    elif args.unregister_ui_plugin:
        register.ui_plugin(unregister=True)
    elif args.enable_intelligence:
        register.cluster()
    elif args.disable_intelligence:
        register.cluster(unregister=True)
    elif args.validate_transport_node_count:
        tn_plugin = PRECHECK_PLUGINS[PrecheckPlugin.TRANSPORT_NODES]()
        tn_plugin.check()
    elif args.validate_license:
        license_plugin = PRECHECK_PLUGINS[PrecheckPlugin.LICENSE]()
        license_plugin.check()
    elif args.validate_platform_type:
        platform_type_plugin = PRECHECK_PLUGINS[PrecheckPlugin.PLATFORM_TYPE]()
        platform_type_plugin.check()
    elif args.validate_advanced_license:
        advanced_license_plugin = PRECHECK_PLUGINS[PrecheckPlugin.ADVANCED_LICENSE]()
        advanced_license_plugin.check()
    else:
        parser.print_help()


try:
    main()
except Exception as e:
    sys.exit(1)
