# keystore/truststore paths
INCLUSTER_KEYSTORE_PATH = "/etc/nsxi/store/keystore.p12"
INCLUSTER_TRUSTSTORE_PATH = "/etc/nsxi/store/truststore.p12"
INCLUSTER_CA_PATH = "/etc/nsxi/store/ca.crt"
EGRESS_KEYSTORE_PATH = "/etc/nsxi/store/egress-keystore.p12"

# limits/requirements
NUM_TRANSPORT_NODE_LIMIT = 250

# add on licenses
ATP_DFW_ADD_ON = "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, " + \
    "NSX DC Advanced, NSX DC Enterprise Plus"
TP_DFS_ADD_ON = "NSX Threat Prevention Add On for Distributed Firewall"
TP_NSX_DFS_ADD_ON = "NSX Threat Prevention Add On for NSX Distributed Firewall"
ATP_ADD_ON = "NSX Advanced Threat Prevention"
ATP_GW_FW_ISO_ADD_ON = "NSX Advanced Threat Prevention Add On for Gateway Firewall – ISO"

VALID_LICENSE_LIST = [
    "NSX Advanced with Advanced Threat Prevention",
    "NSX Advanced with Threat Prevention",
    "NSX Data Center Enterprise Plus",
    "NSX Data Center Evaluation",
    "NSX Enterprise Plus (Subscription)",
    "NSX Enterprise Plus with Threat Prevention",
    "NSX Enterprise Plus with Advanced Threat Prevention",
    "NSX-T Enterprise Plus",
    "NSX-T Evaluation",
    "NSX Firewall",
    "NSX Firewall with Advanced Threat Prevention",
    "NSX Firewall with Baremetal",
    "NSX Firewall Evaluation",
    "NSX Data Center SP Base",
    "NSX Data Center SP Professional",
    "NSX Data Center SP Advanced",
    "NSX Data Center SP Enterprise Plus",
    "NSX Distributed Firewall",
    "NSX Distributed Firewall with Threat Prevention",
    "NSX Distributed Firewall with Advanced Threat Prevention",
    "VMware Container Networking with Antrea Enterprise"
]

VALID_COMBO_LICENSE_LIST = [
    ["NSX Data Center Advanced", ATP_ADD_ON],
    ["NSX Data Center Enterprise Plus", ATP_ADD_ON],
    ["NSX Firewall", ATP_ADD_ON],
    ["NSX-T Advanced", ATP_ADD_ON],
    ["NSX-T Enterprise Plus", ATP_ADD_ON],

    ["NSX Data Center Advanced", TP_DFS_ADD_ON],
    ["NSX Data Center Enterprise Plus", TP_DFS_ADD_ON],
    ["NSX Distributed Firewall", TP_DFS_ADD_ON],
    ["NSX-T Advanced", TP_DFS_ADD_ON],
    ["NSX-T Enterprise Plus", TP_DFS_ADD_ON],

    ["NSX Data Center Advanced", TP_NSX_DFS_ADD_ON],
    ["NSX-T Advanced", TP_NSX_DFS_ADD_ON],

    ["NSX Data Center Advanced", ATP_DFW_ADD_ON],
    ["NSX Data Center Enterprise Plus", ATP_DFW_ADD_ON],
    ["NSX Distributed Firewall", TP_DFS_ADD_ON, ATP_DFW_ADD_ON],
    ["NSX-T Advanced", ATP_DFW_ADD_ON],
    ["NSX-T Enterprise Plus", ATP_DFW_ADD_ON]
]

ADVANCED_LICENSE_LIST = [
    "NSX Advanced with Advanced Threat Prevention",
    "NSX Data Center Evaluation",
    "NSX Distributed Firewall with Advanced Threat Prevention",
    "NSX Enterprise Plus with Advanced Threat Prevention",
    "NSX Firewall with Advanced Threat Prevention",
    "NSX-T Evaluation"
]

ADVANCED_COMBO_LICENSE_LIST = [
    ["NSX Data Center Advanced", ATP_ADD_ON],
    ["NSX Data Center Enterprise Plus", ATP_ADD_ON],
    ["NSX Distributed Firewall", ATP_ADD_ON],
    ["NSX Firewall", ATP_ADD_ON],
    ["NSX-T Advanced", ATP_ADD_ON],
    ["NSX-T Enterprise Plus", ATP_ADD_ON],

    ["NSX Data Center Advanced", ATP_DFW_ADD_ON],
    ["NSX Data Center Enterprise Plus", ATP_DFW_ADD_ON],
    ["NSX Distributed Firewall", ATP_DFW_ADD_ON],
    ["NSX-T Advanced", ATP_DFW_ADD_ON],
    ["NSX-T Enterprise Plus", ATP_DFW_ADD_ON]
]

# REST headers
BASE_HEADERS = {'Content-Type': 'application/json'}
RBAC_IN_CLUSTER_HEADER = {'x-nsx-roles': 'ZW50ZXJwcmlzZV9hZG1pbgo='}

# API endpoints/hosts
CLUSTER_API_HOST = "cluster-api"
MONITOR_API_HOST = "monitor"
NSX_MANAGER_HOST = "external-nsx-manager"


# Case should match response from Monitor API
class PlatformFormFactor:
    ADVANCED = "ADVANCED"
    STANDARD = "STANDARD"
    EVALUATION = "EVALUATION"


class Feature:
    INTELLIGENCE = "intelligence"


# Precheck Plugins
class PrecheckPlugin:
    LICENSE = "license"
    TRANSPORT_NODES = "transport_nodes"
    PLATFORM_TYPE = "platform_type"
    ADVANCED_LICENSE = "advanced_license"


class CheckStatus:
    SUCCESS = "SUCCESS"
    FAILED = "FAILED"
    WARNING = "WARNING"
    SKIPPED = "SKIPPED"
    INPROGRESS = "INPROGRESS"
    STOPPING = "STOPPING"
    STOPPED = "STOPPED"


class Url:
    class InCluster:
        POST_REGISTER_UI_PLUGIN = "https://{service_host}:{service_port}/post-deployment"
        POST_REPORT_PRECHECK = "https://{service_host}:{service_port}/report/precheck"
        GET_PLATFORM_STATUS = "https://{service_host}:{service_port}/api/v1/platform/monitor/platform/status"
        GET_FEATURE_INTEL_CONFIG = "https://{service_host}:{service_port}/features/intelligence/config"

    class Egress:
        GET_TRANSPORT_NODES = "https://{service_host}:443/api/v1/transport-nodes".format(
            service_host=NSX_MANAGER_HOST)
        GET_LICENSE_ALL = "https://{service_host}:443/api/v1/licenses".format(
            service_host=NSX_MANAGER_HOST)
        GET_CLUSTER_REGISTRATION = (
            "https://{service_host}:443/policy/api/v1/infra/sites/napp/registration"
            .format(service_host=NSX_MANAGER_HOST))
        PATCH_CLUSTER_REGISTRATION = (
            "https://{service_host}:443/policy/api/v1/infra/sites/napp/registration/{cluster_id}")
