import os

from hombre.constants import CLUSTER_API_HOST
from hombre.constants import NSX_MANAGER_HOST
from hombre.constants import Url
from hombre.utils import requests_wrapper


def ui_plugin(unregister=False):
    try:
        # create request parameters
        cluster_api_port = os.environ["CLUSTER_API_SERVICE_PORT"]
        url = Url.InCluster.POST_REGISTER_UI_PLUGIN.format(
            service_host=CLUSTER_API_HOST,
            service_port=cluster_api_port)
        req_data = {
            "service_names": ["intelligence"],
            "action": "unregister" if unregister else "register",
        }
        print("Calling intelligence UI plugin (un)registration API on cluster-api service")
        requests_wrapper.incluster_request('POST', url, data=req_data)
    except Exception as e:
        print(e)
        raise


def cluster(unregister=False):
    try:
        # get cluster-id from NSX
        url = Url.Egress.GET_CLUSTER_REGISTRATION
        print("Calling GET cluster registration.")
        json_response = requests_wrapper.egress_request("GET", url)
        cluster_id = None
        for cluster_item in json_response["napp_registration_results"]:
            cluster_id = cluster_item["cluster_id"]
        if not cluster_id:
            raise Exception("NSX Application Platform cluster registration not found")

        # PATCH is_intelligence_enabled for the given cluster_id
        url = Url.Egress.PATCH_CLUSTER_REGISTRATION.format(
            service_host=NSX_MANAGER_HOST,
            cluster_id=cluster_id)
        req_data = {
            "cluster_id": cluster_id,
            "is_intelligence_enabled": False if unregister else True
        }
        requests_wrapper.egress_request("PATCH", url, data=req_data, headers={'X-Allow-Overwrite': 'true'})
    except Exception as e:
        print(e)
        raise
