from hombre.constants import CheckStatus
from hombre.constants import Feature
from hombre.constants import PrecheckPlugin
from hombre.constants import Url
from hombre.constants import ADVANCED_LICENSE_LIST
from hombre.constants import ADVANCED_COMBO_LICENSE_LIST
from hombre.precheck.plugin_base import PluginBase
from hombre.utils import requests_wrapper
import copy


class PluginAdvancedLicense(PluginBase):
    """
    check if the advanced license is installed, reports WARNING if not installed
    """
    id = PrecheckPlugin.ADVANCED_LICENSE
    name = "feature.precheck.advancedLicenseName"
    desc = "feature.precheck.advancedLicenseDesc"
    feature = Feature.INTELLIGENCE
    advanced_license_combo_list_copy = copy.deepcopy(
        ADVANCED_COMBO_LICENSE_LIST)
    complete_advanced_license_list = ADVANCED_LICENSE_LIST + ADVANCED_COMBO_LICENSE_LIST

    def check(self):
        try:
            self.report_check_status(CheckStatus.INPROGRESS, "")
            # create request parameters
            print("Calling NSX manager to get license information")
            json_response = requests_wrapper.egress_request(
                'GET', Url.Egress.GET_LICENSE_ALL)
            advanced_license_found = False
            for license_item in json_response["results"]:
                if (license_item["description"] in ADVANCED_LICENSE_LIST
                        and not license_item["is_expired"]):
                    advanced_license_found = True
                    break
                for combo_list in self.advanced_license_combo_list_copy:
                    if (license_item["description"] in combo_list
                            and not license_item["is_expired"]):
                        combo_list.remove(license_item["description"])

            for combo_list in self.advanced_license_combo_list_copy:
                if not combo_list:
                    advanced_license_found = True

            if advanced_license_found:
                self.report_check_status(
                    CheckStatus.SUCCESS, "feature.precheck.advancedLicensePassReason")
            else:
                self.report_check_status(
                    CheckStatus.WARNING, "feature.precheck.advancedLicenseFailReason")
        except Exception as e:
            self.report_check_status(
                CheckStatus.FAILED, "feature.precheck.nsxApiInvocationFailedReason")
            print(e)
            raise
