import os

from hombre.constants import CLUSTER_API_HOST
from hombre.constants import Url
from hombre.utils import requests_wrapper


class PluginCore(type):
    def __init__(cls, name, bases, attrs):
        super(PluginCore, cls).__init__(name, bases, attrs)
        if not hasattr(cls, 'plugins'):
            # This branch only executes when processing the mount point itself.
            # So, since this is a new plugin type, not an implementation, this
            # class shouldn't be registered as a plugin. Instead, it sets up a
            # list where plugins can be registered later.
            cls.plugins = []
        else:
            # This must be a plugin implementation, which should be registered.
            # Simply appending it to the list is all that's needed to keep
            # track of it later.
            if hasattr(cls, 'name'):
                cls.plugins.append(cls)


class PluginBase(object, metaclass=PluginCore):
    """
    The base class for plugin.
    All pre-checks must implement this base class.

    This provides some convenience methods to invoke common code
    to report status.
    """

    def __init__(self):
        """
        Plugin Initialization
        """

    def check(self):
        """
        Perform the pre-check for this particular plugin

        :return:
        """
        raise NotImplementedError

    def report_check_status(self, status, reason):
        try:
            # create request parameters
            cluster_api_port = os.environ["CLUSTER_API_SERVICE_PORT"]
            url = Url.InCluster.POST_REPORT_PRECHECK.format(
                service_host=CLUSTER_API_HOST,
                service_port=cluster_api_port)
            req_data = {
                "id": self.id,
                "name": self.name,
                "desc": self.desc,
                "feature": self.feature,
                "status": status,
                "reason": reason
            }
            requests_wrapper.incluster_request('POST', url, data=req_data)
        except Exception as e:
            print(e)
            raise
