from hombre.constants import CheckStatus
from hombre.constants import Feature
from hombre.constants import PrecheckPlugin
from hombre.constants import Url
from hombre.constants import VALID_LICENSE_LIST
from hombre.constants import VALID_COMBO_LICENSE_LIST
from hombre.precheck.plugin_base import PluginBase
from hombre.utils import requests_wrapper
import copy


class PluginLicense(PluginBase):
    id = PrecheckPlugin.LICENSE
    name = "feature.precheck.licenseName"
    desc = "feature.precheck.licenseDesc"
    feature = Feature.INTELLIGENCE
    license_combo_copy_list = copy.deepcopy(VALID_COMBO_LICENSE_LIST)
    complete_license_list = VALID_LICENSE_LIST + VALID_COMBO_LICENSE_LIST

    def check(self):
        try:
            self.report_check_status(CheckStatus.INPROGRESS, "")
            # create request parameters
            print("Calling NSX manager to get license information")
            json_response = requests_wrapper.egress_request(
                'GET', Url.Egress.GET_LICENSE_ALL)
            valid_license_found = False
            for license_item in json_response["results"]:
                if (license_item["description"] in VALID_LICENSE_LIST
                        and not license_item["is_expired"]):
                    valid_license_found = True
                    break
                for combo_list in self.license_combo_copy_list:
                    if (license_item["description"] in combo_list
                            and not license_item["is_expired"]):
                        combo_list.remove(license_item["description"])

            for combo_list in self.license_combo_copy_list:
                if not combo_list:
                    valid_license_found = True

            if not valid_license_found:
                self.report_check_status(
                    CheckStatus.FAILED,
                    "feature.precheck.licenseFailReason: {valid_licenses}".format(
                        valid_licenses=self.complete_license_list))
            else:
                self.report_check_status(CheckStatus.SUCCESS, "feature.precheck.licensePassReason")
        except Exception as e:
            self.report_check_status(
                CheckStatus.FAILED, "feature.precheck.nsxApiInvocationFailedReason")
            print(e)
            raise
