import os

from hombre.constants import CLUSTER_API_HOST
from hombre.constants import MONITOR_API_HOST
from hombre.constants import CheckStatus
from hombre.constants import Feature
from hombre.constants import PlatformFormFactor
from hombre.constants import PrecheckPlugin
from hombre.constants import Url
from hombre.precheck.plugin_base import PluginBase
from hombre.utils import requests_wrapper


class PluginPlatformType(PluginBase):
    id = PrecheckPlugin.PLATFORM_TYPE
    name = "feature.precheck.platformTypeName"
    desc = "feature.precheck.platformTypeDesc"
    feature = Feature.INTELLIGENCE

    def check(self):
        try:
            self.report_check_status(CheckStatus.INPROGRESS, "")

            # get Intelligence feature-config
            cluster_api_port = os.environ["CLUSTER_API_SERVICE_PORT"]
            feature_config_url = Url.InCluster.GET_FEATURE_INTEL_CONFIG.format(
                service_host=CLUSTER_API_HOST,
                service_port=cluster_api_port)
            print("Calling GET for Intelligence feature configuration")
            feature_json_response = requests_wrapper.incluster_request('GET', feature_config_url)

            # create request parameters
            monitor_api_port = os.environ["MONITOR_SERVICE_PORT"]
            url = Url.InCluster.GET_PLATFORM_STATUS.format(
                service_host=MONITOR_API_HOST,
                service_port=monitor_api_port)
            print("Calling NSX manager to get platform information")
            json_response = requests_wrapper.incluster_request('GET', url)

            # validate platform info based on feature config
            if feature_json_response["deployment_chart_name"] == "nsxi-chart-evaluation":
                # either EVALUATION or ADVANCED will work
                if json_response["form_factor"] not in [PlatformFormFactor.ADVANCED, PlatformFormFactor.EVALUATION]:
                    msg = ("feature.precheck.platformTypeFailReason: {required_ff}".format(
                                required_ff=[PlatformFormFactor.ADVANCED, PlatformFormFactor.EVALUATION]))
                    self.report_check_status(CheckStatus.FAILED, msg)
                    return
            else:
                # only ADVANCED will work
                if json_response["form_factor"] != PlatformFormFactor.ADVANCED:
                    msg = ("feature.precheck.platformTypeFailReason: {required_ff}".format(
                        required_ff=[PlatformFormFactor.ADVANCED, PlatformFormFactor.EVALUATION]))
                    self.report_check_status(CheckStatus.FAILED, msg)
                    return
            self.report_check_status(CheckStatus.SUCCESS, "feature.precheck.platformTypePassReason")
        except Exception as e:
            self.report_check_status(
                CheckStatus.FAILED, "feature.precheck.nappApiInvocationFailedReason")
            print(e)
            raise
