import json
import os

from hombre import constants
from hombre.utils import requests_pkcs12


class TlsParamsIncluster:
    def __init__(self):
        self.verify = constants.INCLUSTER_CA_PATH
        self.pkcs12_filename = constants.INCLUSTER_KEYSTORE_PATH
        self.pkcs12_password = os.environ["SSL_CERTIFICATE_PASSWORD"]


class TlsParamsEgress:
    def __init__(self):
        self.verify = False
        self.pkcs12_filename = constants.EGRESS_KEYSTORE_PATH
        self.pkcs12_password = os.environ["EGRESS_CERTIFICATE_PASSWORD"]


def _invoke_requests(method, url, data=None, headers=None, egress=False):
    try:
        # setup TLS params
        tls_params = TlsParamsEgress() if egress else TlsParamsIncluster()

        # append headers if provided, else use defaults
        if headers:
            headers.update(constants.BASE_HEADERS)
        else:
            headers = constants.BASE_HEADERS
        print("calling {method} {url} {data}".format(
            method=method, url=url, data=data))
        # encode data to UTF-8
        encoded_data = json.dumps(data).encode("utf-8")
        r = requests_pkcs12.request(
            method, url, data=encoded_data, headers=headers,
            verify=tls_params.verify,
            pkcs12_filename=tls_params.pkcs12_filename,
            pkcs12_password=tls_params.pkcs12_password)
        print("response {response}".format(response=r.text))
        if not r.ok:
            raise Exception("REST FAILED: {reason}"
                            .format(reason=r.reason))
        else:
            print("REST OK")
            return r.json()
    except Exception:
        raise


def incluster_request(method, url, data=None, headers=None):
    if headers:
        headers.update(constants.RBAC_IN_CLUSTER_HEADER)
    else:
        headers = constants.RBAC_IN_CLUSTER_HEADER
    return _invoke_requests(method=method, url=url, data=data,
                            headers=headers, egress=False)


def egress_request(method, url, data=None, headers=None):
    return _invoke_requests(method=method, url=url, data=data,
                            headers=headers, egress=True)
