import os
import unittest
from unittest.mock import patch

from hombre.constants import PrecheckPlugin, Url, CLUSTER_API_HOST, CheckStatus, PlatformFormFactor
from hombre.precheck.plugin_base import PluginBase
from test import mock_method

PRECHECK_PLUGINS = {p.id: p for p in PluginBase.plugins}


@patch.dict(os.environ, {"CLUSTER_API_SERVICE_PORT": "443"})
@patch.dict(os.environ, {"MONITOR_SERVICE_PORT": "443"})
class TestPlatformTypePlugin(unittest.TestCase):

    plugin = PRECHECK_PLUGINS[PrecheckPlugin.PLATFORM_TYPE]()

    @patch('hombre.utils.requests_wrapper.incluster_request', side_effect=mock_method.mock_platform_type_adv_pass)
    def test_precheck_platform_type_adv_pass(self, incluster_request_mock):
        self.plugin.check()

        incluster_request_mock.assert_called_with(
            "POST",
            Url.InCluster.POST_REPORT_PRECHECK.format(
                service_host=CLUSTER_API_HOST,
                service_port="443"),
            data={
                "id": self.plugin.id,
                "name": self.plugin.name,
                "desc": self.plugin.desc,
                "feature": self.plugin.feature,
                "status": CheckStatus.SUCCESS,
                "reason": "feature.precheck.platformTypePassReason"
            }
        )

    @patch('hombre.utils.requests_wrapper.incluster_request', side_effect=mock_method.mock_platform_type_adv_fail)
    def test_precheck_platform_type_adv_fail(self, incluster_request_mock):
        self.plugin.check()

        incluster_request_mock.assert_called_with(
            "POST",
            Url.InCluster.POST_REPORT_PRECHECK.format(
                service_host=CLUSTER_API_HOST,
                service_port="443"),
            data={
                "id": self.plugin.id,
                "name": self.plugin.name,
                "desc": self.plugin.desc,
                "feature": self.plugin.feature,
                "status": CheckStatus.FAILED,
                "reason": "feature.precheck.platformTypeFailReason: {required_ff}".format(
                    required_ff=[PlatformFormFactor.ADVANCED, PlatformFormFactor.EVALUATION])
            }
        )


if __name__ == '__main__':
    unittest.main()
