import os
import unittest
from unittest.mock import patch

from hombre.constants import PrecheckPlugin, Url, CLUSTER_API_HOST, CheckStatus, NUM_TRANSPORT_NODE_LIMIT
from hombre.precheck.plugin_base import PluginBase
from test import mock_method

PRECHECK_PLUGINS = {p.id: p for p in PluginBase.plugins}


@patch.dict(os.environ, {"CLUSTER_API_SERVICE_PORT": "443"})
@patch.dict(os.environ, {"MONITOR_SERVICE_PORT": "443"})
class TestPlatformTypePlugin(unittest.TestCase):

    plugin = PRECHECK_PLUGINS[PrecheckPlugin.TRANSPORT_NODES]()

    @patch('hombre.utils.requests_wrapper.incluster_request', side_effect=mock_method.mock_incluster_transport_node)
    @patch('hombre.utils.requests_wrapper.egress_request', side_effect=mock_method.mock_egress_transport_node_pass)
    def test_precheck_transport_node_pass(self, incluster_request_mock, egress_request_mock):
        self.plugin.check()

        egress_request_mock.assert_called_once()
        incluster_request_mock.assert_called_with(
            method="POST",
            url=Url.InCluster.POST_REPORT_PRECHECK.format(
                service_host=CLUSTER_API_HOST,
                service_port="443"),
            data={
                "id": self.plugin.id,
                "name": self.plugin.name,
                "desc": self.plugin.desc,
                "feature": self.plugin.feature,
                "status": CheckStatus.SUCCESS,
                "reason": "feature.precheck.transportNodesPassReason"
            }
        )

    @patch('hombre.utils.requests_wrapper.incluster_request', side_effect=mock_method.mock_incluster_transport_node)
    @patch('hombre.utils.requests_wrapper.egress_request', side_effect=mock_method.mock_egress_transport_node_fail)
    def test_precheck_transport_node_fail(self, incluster_request_mock, egress_request_mock):
        self.plugin.check()

        egress_request_mock.assert_called_once()
        incluster_request_mock.assert_called_with(
            method="POST",
            url=Url.InCluster.POST_REPORT_PRECHECK.format(
                service_host=CLUSTER_API_HOST,
                service_port="443"),
            data={
                "id": self.plugin.id,
                "name": self.plugin.name,
                "desc": self.plugin.desc,
                "feature": self.plugin.feature,
                "status": CheckStatus.SUCCESS,
                "reason": "feature.precheck.transportNodesFailReason: {exceed_count}".format(
                    exceed_count=(NUM_TRANSPORT_NODE_LIMIT - 251))
            }
        )
